==> 0.10.1.tar.gz: lib/bloc/rewards_module/pages/app_account_detail_add.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'package:shared_preferences/shared_preferences.dart';

import '../../../NetworkFile/calls.dart';
import '../../../models/base_res.dart';
import '../../../models/business_accounting_register.dart';
import '../../../utils/app_buttons.dart';
import '../../../utils/basicInfo.dart';
import '../../../utils/colors.dart';
import '../../../utils/custom_app_bar.dart';
import '../../../utils/customcard.dart';
import '../../../utils/hexColors.dart';
import '../../../utils/localization.dart';
import '../../../utils/locator.dart';
import '../../../utils/someCommonMixins.dart';
import '../../../utils/text_styling.dart';
import '../../../utils/toast_builder.dart';
import '../../common_widgets/dialog_month_picker.dart';


class AddAccountDetails extends StatefulWidget {
  final CommonCardData? data;
  final  Function refreshCallBack;
  AddAccountDetails({required this.data, required this.refreshCallBack});
  @override
  _AddAccountDetails createState() => _AddAccountDetails();
}

class _AddAccountDetails extends State<AddAccountDetails> with CommonMixins {
  String financialYear = "1st month of financial year";

  TextStyleElements? styleElements;
  SharedPreferences prefs = locatorRewards<SharedPreferences>();
  TextEditingController gstController = TextEditingController();
  TextEditingController panController = TextEditingController();
  TextEditingController cinController = TextEditingController();
  TextEditingController tanController = TextEditingController();
  bool isEdit = false;
  BasicInfo? basicInfo = BasicInfo();
  @override
  void initState() {
    super.initState();
    if (widget.data != null) {
      print(jsonEncode(widget.data!));
      isEdit = widget.data!.textTwo != null ||
          widget.data!.textSix != null ||
          widget.data!.textTen != null ||
          widget.data!.textTwelve != null;
      financialYear = widget.data!.textTwo ?? "1st month of financial year";
      gstController.text = widget.data!.textSix ?? "";
      panController.text =
          widget.data!.textEight != null && widget.data!.textEight != "null"
              ? widget.data!.textEight!
              : "";
      cinController.text = widget.data!.textTen ?? "";
      tanController.text = widget.data!.textTwelve ?? "";
    }
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    final dateStart = GestureDetector(
      onTap: () {
        showDialog(
            context: context,
            builder: (BuildContext context) {
              return MonthPickerDialog(monthPicked: (String month) {
                setState(() {
                  financialYear = month;
                });
              });
            });
      },
      child: Padding(
        padding: const EdgeInsets.all(8.0),
        child: Container(
            padding: EdgeInsets.all(8),
            alignment: Alignment.center,
            decoration: BoxDecoration(
              border: Border(
                bottom: BorderSide(
                  //
                  color: HexColor(AppColors.appMainColor33),
                  width: 1.0,
                ),
              ), // set border width
            ),
            child: Align(
              alignment: Alignment.centerLeft,
              child: Text(
                "$financialYear".capitalize,
                overflow: TextOverflow.ellipsis,
                textAlign: TextAlign.left,
                style: styleElements!.bodyText2ThemeScalable(context),
              ),
            )),
      ),
    );

    final gst = Container(
      padding: EdgeInsets.only(bottom: 8),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(12),
        color: HexColor(AppColors.appColorBackground),
      ),
      child: TextFormField(
        validator: validateTextField,
        controller: gstController,
        onSaved: (value) {},
        inputFormatters: [
          FilteringTextInputFormatter.allow(RegExp("[0-9a-zA-Z]")),
        ],
        decoration: InputDecoration(
            hintText: "GST number",
            contentPadding: EdgeInsets.only(left: 12, top: 16, bottom: 8),
            border:
                UnderlineInputBorder(borderRadius: BorderRadius.circular(12)),
            floatingLabelBehavior: FloatingLabelBehavior.auto,
            labelText: "Enter GST number"),
      ),
    );
    final pan = Container(
      padding: EdgeInsets.only(bottom: 8),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(12),
        color: HexColor(AppColors.appColorBackground),
      ),
      child: TextFormField(
        validator: validateTextField,
        controller: panController,
        textCapitalization: TextCapitalization.words,
        onSaved: (value) {},
        inputFormatters: [
          FilteringTextInputFormatter.allow(RegExp("[0-9a-zA-Z]")),
        ],
        decoration: InputDecoration(
            hintText: "PAN number",
            contentPadding: EdgeInsets.only(left: 12, top: 16, bottom: 8),
            border:
                UnderlineInputBorder(borderRadius: BorderRadius.circular(12)),
            floatingLabelBehavior: FloatingLabelBehavior.auto,
            labelText: "Enter PAN number"),
      ),
    );
    final cin = Container(
      padding: EdgeInsets.only(bottom: 8),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(12),
        color: HexColor(AppColors.appColorBackground),
      ),
      child: TextFormField(
        validator: validateTextField,
        controller: cinController,
        onSaved: (value) {},
        inputFormatters: [
          FilteringTextInputFormatter.allow(RegExp("[0-9a-zA-Z]")),
        ],
        decoration: InputDecoration(
            hintText: "CIN number",
            contentPadding: EdgeInsets.only(left: 12, top: 16, bottom: 8),
            border:
                UnderlineInputBorder(borderRadius: BorderRadius.circular(12)),
            floatingLabelBehavior: FloatingLabelBehavior.auto,
            labelText: "Enter CIN number"),
      ),
    );
    final tan = Container(
      padding: EdgeInsets.only(bottom: 8),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(12),
        color: HexColor(AppColors.appColorBackground),
      ),
      child: TextFormField(
        validator: validateTextField,
        controller: tanController,
        onSaved: (value) {},
        inputFormatters: [
          FilteringTextInputFormatter.allow(RegExp("[0-9a-zA-Z]")),
        ],
        decoration: InputDecoration(
            hintText: "TAN number",
            contentPadding: EdgeInsets.only(left: 12, top: 16, bottom: 8),
            border:
                UnderlineInputBorder(borderRadius: BorderRadius.circular(12)),
            floatingLabelBehavior: FloatingLabelBehavior.auto,
            labelText: "Enter TAN number"),
      ),
    );

    return SafeArea(
      child: Scaffold(
        appBar: appAppBar().getCustomAppBar(context,
            appBarTitle: AppLocalizationsRewards.of(context)!
                .translate('account_details'), onBackButtonPress: () {
          Navigator.pop(context);
        }),
        body: appListCard(
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              Row(children: [
                Flexible(
                  child: dateStart,
                ),
              ]),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: gst,
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: pan,
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: cin,
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: tan,
              )
            ],
          ),
        ),
        bottomNavigationBar: Container(
          height: 72,
          child: Center(
            child: Row(
              children: [
                Spacer(),
                appTextButton(
                  color: HexColor(AppColors.appMainColor),
                  onPressed: () {
                    // if (isCheck()) {
                    setAccountingDetails();
                    // }
                  },
                  child: Text(
                    AppLocalizationsRewards.of(context)!.translate('save_exit'),
                    style: styleElements!
                        .headline6ThemeScalableW(context)
                        .copyWith(color: HexColor(AppColors.appColorWhite)),
                  ),
                ),
                const SizedBox(
                  width: 16,
                )
              ],
            ),
          ),
        ),
      ),
    );
  }

  void setAccountingDetails() async {
    BusinessAccountRegisterRequest payload = BusinessAccountRegisterRequest();

    payload.finStartMonth = financialYear == "1st month of financial year" ? null : financialYear;
    payload.cin = cinController.text;
    payload.pan = panController.text;
    payload.gst = gstController.text;
    payload.tan = tanController.text;
    payload.id = isEdit ? int.parse(widget.data!.id!) : null;
    payload.businessId = basicInfo!.businessId;
    Calls()
        .call(
            jsonEncode(payload),
            context,
            isEdit
                ? basicInfo!.businessAcountEdit
                : basicInfo!.accountRegister)
        .then((value) {
      Navigator.pop(context, true);
     widget. refreshCallBack();
    });
  }

  bool isCheck() {
    if (financialYear != '1st month of financial year') {
      if (financialYear != '1st month of tax year') {
        if (gstController.text.isNotEmpty) {
          if (panController.text.isNotEmpty) {
            if (cinController.text.isNotEmpty) {
              if (tanController.text.isNotEmpty) {
                return true;
              } else {
                ToastBuilder().showToast('Please enter tan number', context,
                    HexColor(AppColors.information));
                return false;
              }
            } else {
              ToastBuilder().showToast('Please enter cin number', context,
                  HexColor(AppColors.information));
              return false;
            }
          } else {
            ToastBuilder().showToast('Please enter pan number', context,
                HexColor(AppColors.information));
            return false;
          }
        } else {
          ToastBuilder().showToast('Please enter gst number', context,
              HexColor(AppColors.information));
          return false;
        }
      } else {
        ToastBuilder().showToast('Please select first month of tax year',
            context, HexColor(AppColors.information));
        return false;
      }
    } else {
      ToastBuilder().showToast('Please select first month of financial year',
          context, HexColor(AppColors.information));
      return false;
    }
  }
}

==> 0.11.1.tar.gz: lib/bloc/rewards_module/pages/app_account_detail_add.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'package:shared_preferences/shared_preferences.dart';

import '../../../NetworkFile/calls.dart';
import '../../../models/base_res.dart';
import '../../../models/business_accounting_register.dart';
import '../../../utils/app_buttons.dart';
import '../../../utils/basicInfo.dart';
import '../../../utils/colors.dart';
import '../../../utils/custom_app_bar.dart';
import '../../../utils/customcard.dart';
import '../../../utils/hexColors.dart';
import '../../../utils/localization.dart';
import '../../../utils/locator.dart';
import '../../../utils/someCommonMixins.dart';
import '../../../utils/text_styling.dart';
import '../../../utils/toast_builder.dart';
import '../../common_widgets/dialog_month_picker.dart';

class AddAccountDetails extends StatefulWidget {
  final CommonCardData? data;
  final Function refreshCallBack;

  AddAccountDetails({required this.data, required this.refreshCallBack});

  @override
  _AddAccountDetails createState() => _AddAccountDetails();
}

class _AddAccountDetails extends State<AddAccountDetails> with CommonMixins {
  String financialYear = "1st month of financial year";

  TextStyleElements? styleElements;
  SharedPreferences prefs = locatorRewards<SharedPreferences>();
  TextEditingController gstController = TextEditingController();
  TextEditingController panController = TextEditingController();
  TextEditingController cinController = TextEditingController();
  TextEditingController tanController = TextEditingController();
  bool isEdit = false;
  BasicInfo? basicInfo = BasicInfo();

  @override
  void initState() {
    super.initState();
    if (widget.data != null) {
      print(jsonEncode(widget.data!));
      isEdit = widget.data!.textTwo != null ||
          widget.data!.textSix != null ||
          widget.data!.textTen != null ||
          widget.data!.textTwelve != null;
      financialYear = widget.data!.textTwo ?? "1st month of financial year";
      gstController.text = widget.data!.textSix ?? "";
      panController.text =
          widget.data!.textEight != null && widget.data!.textEight != "null"
              ? widget.data!.textEight!
              : "";
      cinController.text = widget.data!.textTen ?? "";
      tanController.text = widget.data!.textTwelve ?? "";
    }
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    final dateStart = GestureDetector(
      onTap: () {
        showDialog(
            context: context,
            builder: (BuildContext context) {
              return MonthPickerDialog(monthPicked: (String month) {
                setState(() {
                  financialYear = month;
                });
              });
            });
      },
      child: Padding(
        padding: const EdgeInsets.all(8.0),
        child: Container(
            padding: EdgeInsets.all(8),
            alignment: Alignment.center,
            decoration: BoxDecoration(
              border: Border(
                bottom: BorderSide(
                  //
                  color: HexColor(AppColors.appMainColor33),
                  width: 1.0,
                ),
              ), // set border width
            ),
            child: Align(
              alignment: Alignment.centerLeft,
              child: Text(
                "$financialYear".capitalize,
                overflow: TextOverflow.ellipsis,
                textAlign: TextAlign.left,
                style: styleElements!.bodyText2ThemeScalable(context),
              ),
            )),
      ),
    );

    final gst = Container(
      padding: EdgeInsets.only(bottom: 8),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(12),
        color: HexColor(AppColors.appColorBackground),
      ),
      child: TextFormField(
        validator: validateTextField,
        controller: gstController,
        onSaved: (value) {},
        inputFormatters: [
          FilteringTextInputFormatter.allow(RegExp("[0-9a-zA-Z]")),
        ],
        decoration: InputDecoration(
            hintText: "GST number",
            contentPadding: EdgeInsets.only(left: 12, top: 16, bottom: 8),
            border:
                UnderlineInputBorder(borderRadius: BorderRadius.circular(12)),
            floatingLabelBehavior: FloatingLabelBehavior.auto,
            labelText: "Enter GST number"),
      ),
    );
    final pan = Container(
      padding: EdgeInsets.only(bottom: 8),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(12),
        color: HexColor(AppColors.appColorBackground),
      ),
      child: TextFormField(
        validator: validateTextField,
        controller: panController,
        textCapitalization: TextCapitalization.words,
        onSaved: (value) {},
        inputFormatters: [
          FilteringTextInputFormatter.allow(RegExp("[0-9a-zA-Z]")),
        ],
        decoration: InputDecoration(
            hintText: "PAN number",
            contentPadding: EdgeInsets.only(left: 12, top: 16, bottom: 8),
            border:
                UnderlineInputBorder(borderRadius: BorderRadius.circular(12)),
            floatingLabelBehavior: FloatingLabelBehavior.auto,
            labelText: "Enter PAN number"),
      ),
    );
    final cin = Container(
      padding: EdgeInsets.only(bottom: 8),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(12),
        color: HexColor(AppColors.appColorBackground),
      ),
      child: TextFormField(
        validator: validateTextField,
        controller: cinController,
        onSaved: (value) {},
        inputFormatters: [
          FilteringTextInputFormatter.allow(RegExp("[0-9a-zA-Z]")),
        ],
        decoration: InputDecoration(
            hintText: "CIN number",
            contentPadding: EdgeInsets.only(left: 12, top: 16, bottom: 8),
            border:
                UnderlineInputBorder(borderRadius: BorderRadius.circular(12)),
            floatingLabelBehavior: FloatingLabelBehavior.auto,
            labelText: "Enter CIN number"),
      ),
    );
    final tan = Container(
      padding: EdgeInsets.only(bottom: 8),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(12),
        color: HexColor(AppColors.appColorBackground),
      ),
      child: TextFormField(
        validator: validateTextField,
        controller: tanController,
        onSaved: (value) {},
        inputFormatters: [
          FilteringTextInputFormatter.allow(RegExp("[0-9a-zA-Z]")),
        ],
        decoration: InputDecoration(
            hintText: "TAN number",
            contentPadding: EdgeInsets.only(left: 12, top: 16, bottom: 8),
            border:
                UnderlineInputBorder(borderRadius: BorderRadius.circular(12)),
            floatingLabelBehavior: FloatingLabelBehavior.auto,
            labelText: "Enter TAN number"),
      ),
    );

    return SafeArea(
      child: Scaffold(
        appBar: appAppBar().getCustomAppBar(context,
            appBarTitle: AppLocalizationsRewards.of(context)!
                .translate('account_details'), onBackButtonPress: () {
          Navigator.pop(context);
        }),
        body: appListCard(
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              Row(children: [
                Flexible(
                  child: dateStart,
                ),
              ]),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: gst,
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: pan,
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: cin,
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: tan,
              )
            ],
          ),
        ),
        bottomNavigationBar: Container(
          height: 72,
          child: Center(
            child: Row(
              children: [
                Spacer(),
                appTextButton(
                  color: HexColor(AppColors.appMainColor),
                  onPressed: () {
                    // if (isCheck()) {
                    setAccountingDetails();
                    // }
                  },
                  child: Text(
                    AppLocalizationsRewards.of(context)!.translate('save_exit'),
                    style: styleElements!
                        .headline6ThemeScalableW(context)
                        .copyWith(color: HexColor(AppColors.appColorWhite)),
                  ),
                ),
                const SizedBox(
                  width: 16,
                )
              ],
            ),
          ),
        ),
      ),
    );
  }

  void setAccountingDetails() async {
    BusinessAccountRegisterRequest payload = BusinessAccountRegisterRequest();

    payload.finStartMonth =
        financialYear == "1st month of financial year" ? null : financialYear;
    payload.cin = cinController.text;
    payload.pan = panController.text;
    payload.gst = gstController.text;
    payload.tan = tanController.text;
    payload.id = isEdit ? int.parse(widget.data!.id!) : null;
    payload.businessId = basicInfo!.businessId;
    Calls()
        .call(jsonEncode(payload), context,
            isEdit ? basicInfo!.businessAcountEdit : basicInfo!.accountRegister)
        .then((value) {
      Navigator.pop(context, true);
      widget.refreshCallBack();
    });
  }

  bool isCheck() {
    if (financialYear != '1st month of financial year') {
      if (financialYear != '1st month of tax year') {
        if (gstController.text.isNotEmpty) {
          if (panController.text.isNotEmpty) {
            if (cinController.text.isNotEmpty) {
              if (tanController.text.isNotEmpty) {
                return true;
              } else {
                ToastBuilder().showToast('Please enter tan number', context,
                    HexColor(AppColors.information));
                return false;
              }
            } else {
              ToastBuilder().showToast('Please enter cin number', context,
                  HexColor(AppColors.information));
              return false;
            }
          } else {
            ToastBuilder().showToast('Please enter pan number', context,
                HexColor(AppColors.information));
            return false;
          }
        } else {
          ToastBuilder().showToast('Please enter gst number', context,
              HexColor(AppColors.information));
          return false;
        }
      } else {
        ToastBuilder().showToast('Please select first month of tax year',
            context, HexColor(AppColors.information));
        return false;
      }
    } else {
      ToastBuilder().showToast('Please select first month of financial year',
          context, HexColor(AppColors.information));
      return false;
    }
  }
}
